      * [Custom Reports: Workspace Best Practice](https://help.sap.com/docs/leanix/ea/workspace-best-practice-report?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Cost Management](https://help.sap.com/docs/leanix/ea/cost-management?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Embedding a Report in SharePoint](https://help.sap.com/docs/leanix/ea/embedding-report-in-sharepoint?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Diagrams](https://help.sap.com/docs/leanix/ea/diagrams?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Creating Diagrams and Adding Basic Elements](https://help.sap.com/docs/leanix/ea/creating-your-first-diagram-and-adding-basic-elements?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Viewing and Analyzing Diagrams](https://help.sap.com/docs/leanix/ea/viewing-and-analyzing-diagrams?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Managing Diagram Versions, Importing, and Exporting](https://help.sap.com/docs/leanix/ea/diagram-versions-importing-and-exporting?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Free Draw Diagrams](https://help.sap.com/docs/leanix/ea/free-draw?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Data Flow Diagrams](https://help.sap.com/docs/leanix/ea/data-flow?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Diagram Templates](https://help.sap.com/docs/leanix/ea/diagram-templates?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Creating and Editing Diagram Templates](https://help.sap.com/docs/leanix/ea/creating-and-editing-diagram-templates?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Previewing Templates and Creating Diagrams from Templates](https://help.sap.com/docs/leanix/ea/previewing-templates-and-creating-diagrams-from-templates?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Styles and Patterns](https://help.sap.com/docs/leanix/ea/styles-and-patterns?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Fact Sheet Shape Templates](https://help.sap.com/docs/leanix/ea/fact-sheet-shape-templates?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [SAP BTP Reference Architecture Templates](https://help.sap.com/docs/leanix/ea/sap-btp-reference-architecture-templates?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Lucidchart Integration](https://help.sap.com/docs/leanix/ea/lucidchart-integration?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Collaboration](https://help.sap.com/docs/leanix/ea/collaboration?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Surveys](https://help.sap.com/docs/leanix/ea/surveys?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Creating a Survey](https://help.sap.com/docs/leanix/ea/creating-survey?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Sending Out the Surveys](https://help.sap.com/docs/leanix/ea/sending-out-surveys?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Responding to Surveys](https://help.sap.com/docs/leanix/ea/responding-to-surveys?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Managing Surveys and Viewing Results](https://help.sap.com/docs/leanix/ea/managing-surveys-and-viewing-results?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Extended Guide on Survey Features](https://help.sap.com/docs/leanix/ea/extended-guide-on-survey-features?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Calculated Fields in Surveys](https://help.sap.com/docs/leanix/ea/calculated-fields-in-surveys?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [To-Dos](https://help.sap.com/docs/leanix/ea/to-dos?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [AI Capabilities](https://help.sap.com/docs/leanix/ea/ai-capabilities?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Base AI Capabilities](https://help.sap.com/docs/leanix/ea/base-ai-capabilities?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Inventory Builder](https://help.sap.com/docs/leanix/ea/inventory-builder?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Sample Prompts for the Inventory Builder](https://help.sap.com/docs/leanix/ea/sample-prompts-for-inventory-builder?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Joule in SAP LeanIX](https://help.sap.com/docs/leanix/ea/joule-in-sap-leanix?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [AI Agent Hub](https://help.sap.com/docs/leanix/ea/ai-agent-hub?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [AI Agent Hub Dashboard](https://help.sap.com/docs/leanix/ea/ai-agent-hub-dashboard?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Reports for AI Agents](https://help.sap.com/docs/leanix/ea/reports-for-ai-agents?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [SAP Suggestions in Reports](https://help.sap.com/docs/leanix/ea/sap-suggestions-in-reports?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Calculations for AI Agents](https://help.sap.com/docs/leanix/ea/calculations-for-ai-agents?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [MCP Server](https://help.sap.com/docs/leanix/ea/mcp-server?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Connecting to the MCP Server](https://help.sap.com/docs/leanix/ea/connecting-to-mcp-server?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Workspace Views](https://help.sap.com/docs/leanix/ea/workspace-views?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Presentations](https://help.sap.com/docs/leanix/ea/presentations?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Collections](https://help.sap.com/docs/leanix/ea/collections?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Notifications](https://help.sap.com/docs/leanix/ea/notifications?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [User Profile](https://help.sap.com/docs/leanix/ea/user-profile?locale=en-US&state=PRODUCTION&version=CLOUD)
  * [Administrator Guide](https://help.sap.com/docs/leanix/ea/administrator-guide?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Workspace Provisioning from SAP for Me](https://help.sap.com/docs/leanix/ea/workspace-provisioning-from-sap-for-me?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [SAP for Me Super/Cloud Admin for Workspace Provisioning](https://help.sap.com/docs/leanix/ea/sap-for-me-super-cloud-admin-for-workspace-provisioning?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Provisioning SAP LeanIX from SAP for Me (NGCS)](https://help.sap.com/docs/leanix/ea/provisioning-sap-leanix-workspace?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Provisioning SAP LeanIX from SAP for Me (classic)](https://help.sap.com/docs/leanix/ea/workspace-provisioning?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Workspace Administration](https://help.sap.com/docs/leanix/ea/workspace-administration?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Workspace Settings Overview](https://help.sap.com/docs/leanix/ea/workspace-settings-overview?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Manage Workspace Access](https://help.sap.com/docs/leanix/ea/manage-workspace-access?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Status Pages and Status Emails](https://help.sap.com/docs/leanix/ea/status-pages-and-status-emails?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Production and Sandbox Workspaces](https://help.sap.com/docs/leanix/ea/production-and-sandbox-workspaces?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Monitoring the Usage and Adoption of SAP LeanIX](https://help.sap.com/docs/leanix/ea/monitor-usage-and-adoption?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Password Rules](https://help.sap.com/docs/leanix/ea/password-rules?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Basic Settings](https://help.sap.com/docs/leanix/ea/basic-settings?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Branding Settings](https://help.sap.com/docs/leanix/ea/branding-settings?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [General Settings](https://help.sap.com/docs/leanix/ea/general-settings?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Meta Model Configuration](https://help.sap.com/docs/leanix/ea/meta-model-configuration?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Fact Sheet Fields](https://help.sap.com/docs/leanix/ea/fact-sheet-fields?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Fact Sheet Relations](https://help.sap.com/docs/leanix/ea/fact-sheet-relations?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Fact Sheet Permissions](https://help.sap.com/docs/leanix/ea/fact-sheet-permissions?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Conditional Attributes](https://help.sap.com/docs/leanix/ea/conditional-attributes?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Fact Sheet Subtype Management](https://help.sap.com/docs/leanix/ea/fact-sheet-subtype-management?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Custom Fact Sheet Types](https://help.sap.com/docs/leanix/ea/custom-fact-sheet-types?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Fact Sheet Order and Colors](https://help.sap.com/docs/leanix/ea/fact-sheet-order-and-colors?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Subscription Roles](https://help.sap.com/docs/leanix/ea/subscription-roles?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Tagging](https://help.sap.com/docs/leanix/ea/tagging?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Dashboards Settings](https://help.sap.com/docs/leanix/ea/dashboards-settings?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Advanced Settings](https://help.sap.com/docs/leanix/ea/advanced-settings?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Automations](https://help.sap.com/docs/leanix/ea/automations?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Automations Best Practices](https://help.sap.com/docs/leanix/ea/automations-best-practices?locale=en-US&state=PRODUCTION&version=CLOUD)
          * [Automations Best Practices: Selected Use Cases](https://help.sap.com/docs/leanix/ea/automation-examples-selected-use-cases?locale=en-US&state=PRODUCTION&version=CLOUD)
          * [Automations Best Practices: Use Cases by Triggers](https://help.sap.com/docs/leanix/ea/automation-examples-use-cases-by-triggers?locale=en-US&state=PRODUCTION&version=CLOUD)
          * [Automations Best Practices: Automations with Webhooks](https://help.sap.com/docs/leanix/ea/automation-examples-automations-with-webhooks?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Automations with Scripts](https://help.sap.com/docs/leanix/ea/automations-with-scripts?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Examples: Automations with Scripts](https://help.sap.com/docs/leanix/ea/examples-automations-with-scripts?locale=en-US&state=PRODUCTION&version=CLOUD)
          * [Synchronizing Subscriptions Across Related Fact Sheets (Subscription Inheritance)](https://help.sap.com/docs/leanix/ea/synchronizing-subscriptions-across-related-fact-sheets-subscription-inheritance?locale=en-US&state=PRODUCTION&version=CLOUD)
          * [Propagating Business Context Relations to Parent Applications (Relation Inheritance)](https://help.sap.com/docs/leanix/ea/propagating-business-context-relations-to-parent-applications-relation-inheritance?locale=en-US&state=PRODUCTION&version=CLOUD)
          * [Breaking Application Quality Seals when Initiatives Reach End of Life](https://help.sap.com/docs/leanix/ea/breaking-application-quality-seals-when-initiatives-reach-end-of-life?locale=en-US&state=PRODUCTION&version=CLOUD)
          * [Validating the Plan Lifecycle Phase](https://help.sap.com/docs/leanix/ea/validating-plan-lifecycle-phase?locale=en-US&state=PRODUCTION&version=CLOUD)
          * [Updating a Lifecycle Phase and Approving the Quality Seal](https://help.sap.com/docs/leanix/ea/updating-lifecycle-phase-and-approving-quality-seal?locale=en-US&state=PRODUCTION&version=CLOUD)
          * [Syncing Tags with the Current Lifecycle Phases](https://help.sap.com/docs/leanix/ea/syncing-tags-with-current-lifecycle-phases?locale=en-US&state=PRODUCTION&version=CLOUD)
          * [Updating Lifecycle Phases](https://help.sap.com/docs/leanix/ea/updating-lifecycle-phases?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Creating an Automation with a Webhook Action](https://help.sap.com/docs/leanix/ea/automations-webhooks?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Calculations](https://help.sap.com/docs/leanix/ea/calculations?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Calculation Examples](https://help.sap.com/docs/leanix/ea/calculation-examples?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Calculations and Automations: When to Use Each Feature](https://help.sap.com/docs/leanix/ea/calculations-and-automations-when-to-use-each-feature?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Export](https://help.sap.com/docs/leanix/ea/export?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [KPIs](https://help.sap.com/docs/leanix/ea/kpis?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Configuring KPIs](https://help.sap.com/docs/leanix/ea/configuring-kpis?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Managed Code](https://help.sap.com/docs/leanix/ea/managed-code?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Metrics](https://help.sap.com/docs/leanix/ea/metrics?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Notifications Center](https://help.sap.com/docs/leanix/ea/notifications-center?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Configuring the E-Mail Channel](https://help.sap.com/docs/leanix/ea/configuring-e-mail-channel?locale=en-US&state=PRODUCTION&version=CLOUD)
          * [Setting Up a Microsoft Exchange Online Mailbox for Email Notifications](https://help.sap.com/docs/leanix/ea/setting-up-microsoft-exchange-online-mailbox-for-email-notifications?locale=en-US&state=PRODUCTION&version=CLOUD)
          * [Setting Up a Custom SMTP Server for Email Notifications](https://help.sap.com/docs/leanix/ea/setting-up-custom-smtp-server-for-email-notifications?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Configuring the Microsoft Teams Channel](https://help.sap.com/docs/leanix/ea/configuring-microsoft-teams-channel?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Portals](https://help.sap.com/docs/leanix/ea/portals?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Portal FAQs](https://help.sap.com/docs/leanix/ea/portal-faqs?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Portal: Parameterized Links](https://help.sap.com/docs/leanix/ea/portal-parameterized-links?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Downloading Reports from the SAP LeanIX Store](https://help.sap.com/docs/leanix/ea/download-reports?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [To-Dos (Administration)](https://help.sap.com/docs/leanix/ea/to-dos-administration?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Workspace Views Configuration](https://help.sap.com/docs/leanix/ea/workspace-views-configuration?locale=en-US&state=PRODUCTION&version=CLOUD)
  * [User and Access Management](https://help.sap.com/docs/leanix/ea/user-and-access-management?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Managing Users](https://help.sap.com/docs/leanix/ea/managing-users?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Users Overview](https://help.sap.com/docs/leanix/ea/users-overview?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [User Roles and Permissions](https://help.sap.com/docs/leanix/ea/user-roles-and-permissions?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Authorization Model](https://help.sap.com/docs/leanix/ea/authorization-model?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [PII Change Audit Report](https://help.sap.com/docs/leanix/ea/pii-change-audit-report?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Single Sign-On (SSO)](https://help.sap.com/docs/leanix/ea/single-sign-on-sso?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [SSO Configuration Process](https://help.sap.com/docs/leanix/ea/sso-configuration-process?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Migration to the Self-Service SSO Configuration](https://help.sap.com/docs/leanix/ea/migration-to-self-service-sso-configuration?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Configuring SSO with Okta](https://help.sap.com/docs/leanix/ea/configuring-sso-with-okta?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Configuring SSO with Microsoft Entra ID](https://help.sap.com/docs/leanix/ea/configuring-sso-with-microsoft-entra-id?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Configuring SSO with SAP Cloud Identity Services - Identity Authentication Service (IAS)](https://help.sap.com/docs/leanix/ea/configuring-sso-with-sap-cloud-identity-services-identity-authentication-service-ias?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Configuring SSO with PingOne](https://help.sap.com/docs/leanix/ea/configuring-sso-with-pingone?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Configuring SSO with OneLogin](https://help.sap.com/docs/leanix/ea/configuring-sso-with-onelogin?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Configuring SSO with Active Directory Federation Services](https://help.sap.com/docs/leanix/ea/configuring-sso-with-active-directory-federation-services?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [SCIM Provisioning](https://help.sap.com/docs/leanix/ea/scim-provisioning?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Access Tokens Required for SCIM](https://help.sap.com/docs/leanix/ea/access-tokens-required-for-scim?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Configuring SCIM in Okta](https://help.sap.com/docs/leanix/ea/configuring-scim-in-okta?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Configuring SCIM in Microsoft Entra ID](https://help.sap.com/docs/leanix/ea/configuring-scim-in-microsoft-entra-id?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Virtual Workspaces](https://help.sap.com/docs/leanix/ea/virtual-workspaces?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Virtual Workspaces Configuration](https://help.sap.com/docs/leanix/ea/virtual-workspaces-configuration?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Access to SAP for Me](https://help.sap.com/docs/leanix/ea/access-to-sap-for-me?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Setting Up Your Organization's S-User Administrator](https://help.sap.com/docs/leanix/ea/setting-up-your-organization-s-s-user-administrator?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Creating and Managing S-Users in SAP For Me](https://help.sap.com/docs/leanix/ea/creating-and-managing-s-users-in-sap-for-me?locale=en-US&state=PRODUCTION&version=CLOUD)
  * [Discovery and Integrations](https://help.sap.com/docs/leanix/ea/discovery-and-integrations?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Reference Catalog](https://help.sap.com/docs/leanix/ea/reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Business Capabilities in the Reference Catalog](https://help.sap.com/docs/leanix/ea/business-capabilities-in-reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Applications in the Reference Catalog](https://help.sap.com/docs/leanix/ea/applications-in-reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [IT Components in the Reference Catalog](https://help.sap.com/docs/leanix/ea/it-components-in-reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Tech Categories in the Reference Catalog](https://help.sap.com/docs/leanix/ea/tech-categories-in-reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Migrating to the TBM Taxonomy Version 5.0.1 for Tech Categories](https://help.sap.com/docs/leanix/ea/migrating-to-tbm-taxonomy-version-5-0-1-for-tech-categories?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Reference Catalog: Best Practices](https://help.sap.com/docs/leanix/ea/reference-catalog-best-practices?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Reference Catalog: Fact Sheet Naming Conventions](https://help.sap.com/docs/leanix/ea/reference-catalog-fact-sheet-naming-conventions?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Reference Catalog: Provider Tiers, Response Times, and FAQs](https://help.sap.com/docs/leanix/ea/reference-catalog-provider-tiers-response-times-and-faqs?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [SaaS Discovery](https://help.sap.com/docs/leanix/ea/saas-discovery?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [SaaS Discovery Inbox](https://help.sap.com/docs/leanix/ea/saas-discovery-inbox?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Microsoft Defender for Cloud Apps (MDCA) Integration for SaaS Discovery](https://help.sap.com/docs/leanix/ea/microsoft-defender-for-cloud-apps-mdca-integration-for-saas-discovery?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Microsoft Entra ID Integration for SaaS Discovery](https://help.sap.com/docs/leanix/ea/microsoft-entra-id-integration-for-saas-discovery?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Netskope Integration for SaaS Discovery](https://help.sap.com/docs/leanix/ea/netskope-integration-for-saas-discovery?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Okta Integration for SaaS Discovery](https://help.sap.com/docs/leanix/ea/okta-integration-for-saas-discovery?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Zscaler Integration for SaaS Discovery](https://help.sap.com/docs/leanix/ea/zscaler-integration-for-saas-discovery?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [WalkMe Integration for SaaS Discovery](https://help.sap.com/docs/leanix/ea/walkme-integration-for-saas-discovery?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [Self-Built Software Discovery](https://help.sap.com/docs/leanix/ea/self-built-software-discovery?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Workspace Setup for Self-Built Software Discovery](https://help.sap.com/docs/leanix/ea/workspace-setup-for-self-built-software-discovery?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [GitHub Enterprise Integration](https://help.sap.com/docs/leanix/ea/github-enterprise-integration?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Setting Up the GitHub Enterprise Integration](https://help.sap.com/docs/leanix/ea/setting-up-github-enterprise-integration?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [GitHub App Permissions](https://help.sap.com/docs/leanix/ea/github-app-permissions?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Code for Deploying the SAP LeanIX GitHub Agent](https://help.sap.com/docs/leanix/ea/code-for-deploying-sap-leanix-github-agent?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [SBOM Discovery from Build Artifacts](https://help.sap.com/docs/leanix/ea/sbom-discovery-from-build-artifacts?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Microservice Discovery in Your CI/CD Pipeline](https://help.sap.com/docs/leanix/ea/microservice-discovery-in-your-ci-cd-pipeline?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Configuring Your CI/CD Pipeline](https://help.sap.com/docs/leanix/ea/configuring-your-ci-cd-pipeline?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Manifest File and Schema](https://help.sap.com/docs/leanix/ea/manifest-file-and-schema?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Software Bill of Materials (SBOM)](https://help.sap.com/docs/leanix/ea/software-bill-of-materials-sbom?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Generating SBOMs](https://help.sap.com/docs/leanix/ea/generating-sboms?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [SBOM Explorer](https://help.sap.com/docs/leanix/ea/sbom-explorer?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Retrieving SBOM Library Components for Business Applications](https://help.sap.com/docs/leanix/ea/retrieving-sbom-library-components-for-business-applications?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [Tech Stack Discovery from SBOMs](https://help.sap.com/docs/leanix/ea/tech-stack-discovery-from-sboms?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Using the MCP Server for Tech Stack Management](https://help.sap.com/docs/leanix/ea/using-mcp-server-for-tech-stack-management?locale=en-US&state=PRODUCTION&version=CLOUD)
    * [SAP Discovery](https://help.sap.com/docs/leanix/ea/sap-discovery?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [SAP Cloud ALM Integration for SAP Discovery](https://help.sap.com/docs/leanix/ea/sap-discovery-cloud-alm?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Configuring the SAP Cloud ALM Integration](https://help.sap.com/docs/leanix/ea/sap-discovery-configuring-cloud-alm?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Enabling Discovered Flows](https://help.sap.com/docs/leanix/ea/enabling-discovered-flows?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [SAP Build Integration for SAP Discovery](https://help.sap.com/docs/leanix/ea/configuring-sap-build-integration?locale=en-US&state=PRODUCTION&version=CLOUD)
      * [SAP BTP, Cloud Foundry Integration for SAP Discovery](https://help.sap.com/docs/leanix/ea/configuring-sap-btp-cloud-foundry-integration?locale=en-US&state=PRODUCTION&version=CLOUD)
        * [Configuring SAP BTP, Cloud Foundry Integration Using Trusted Certificate Authentication](https://help.sap.com/docs/leanix/ea/configuring-sap-btp-cloud-foundry-integration-using-trusted-certificate-authentication?locale=en-US&state=PRODUCTION&version=CLOUD)
